@@ -1,8 +1,15 @@
 from pca.pca import pca
 
+from pca.pca import (
+    import_example,
+    hotellingsT2,
+    spe_dmodx,
+    )
+
+
 __author__ = 'Erdogan Tasksen'
 __email__ = 'erdogant@gmail.com'
-__version__ = '1.0.2'
+__version__ = '1.5.0'
 
 # module level doc-string
 __doc__ = """
@@ -11,23 +18,33 @@ pca
 
 Description
 -----------
-pca is a python package that performs the principal component analysis and to make insightful plots.
+pca is a python package to perform Principal Component Analysis and to make insightful plots.
 
 Examples
 --------
+>>> from pca import pca
 >>> # Load example data
+>>> from sklearn.datasets import load_iris
 >>> X = pd.DataFrame(data=load_iris().data, columns=load_iris().feature_names, index=load_iris().target)
+>>>
+>>> Initialize
+>>> model = pca(n_components=3)
 >>> # Fit using PCA
 >>> results = model.fit_transform(X)
+>>>
 >>> # Make plots
->>> model.scatter()
->>> ax = model.plot()
->>> ax = model.biplot()
+>>> fig, ax = model.scatter()
+>>> fig, ax = model.plot()
+>>> fig, ax = model.biplot()
+>>> fig, ax = model.biplot(SPE=True, hotellingt2=True)
+>>>
 >>> 3D plots
->>> model.scatter3d()
->>> ax = model.biplot3d()
+>>> fig, ax = model.scatter3d()
+>>> fig, ax = model.biplot3d()
+>>> fig, ax = model.biplot3d(SPE=True, hotellingt2=True)
+>>>
 >>> # Normalize out PCs
->>> X_norm = pca.norm(X)
+>>> X_norm = model.norm(X)
 
 References
 ----------
